@@ -248,6 +248,10 @@ func NewCreateClusterLoader(cmd *Cmd, ngFilter *filter.NodeGroupFilter, ng *api.
 			*clusterConfig.VPC.NAT.Gateway = api.ClusterSingleNAT
 		}
 
+		if err := validateUnsetNodeGroups(l.ClusterConfig); err != nil {
+			return err
+		}
+
 		hasEndpointAccess := func() bool {
 			clusterEndpoints := clusterConfig.VPC.ClusterEndpoints
 			return clusterEndpoints != nil && (clusterEndpoints.PublicAccess != nil || clusterEndpoints.PrivateAccess != nil)
@@ -411,6 +415,9 @@ func NewCreateNodeGroupLoader(cmd *Cmd, ng *api.NodeGroup, ngFilter *filter.Node
 	}
 
 	l.validateWithConfigFile = func() error {
+		if err := validateUnsetNodeGroups(l.ClusterConfig); err != nil {
+			return err
+		}
 		if err := ngFilter.AppendGlobs(l.Include, l.Exclude, l.ClusterConfig.GetAllNodeGroupNames()); err != nil {
 			return err
 		}
@@ -465,6 +472,20 @@ func NewCreateNodeGroupLoader(cmd *Cmd, ng *api.NodeGroup, ngFilter *filter.Node
 	return l
 }
 
+func validateUnsetNodeGroups(clusterConfig *api.ClusterConfig) error {
+	for i, ng := range clusterConfig.NodeGroups {
+		if ng == nil {
+			return fmt.Errorf("invalid ClusterConfig: nodeGroups[%d] is not set", i)
+		}
+	}
+	for i, ng := range clusterConfig.ManagedNodeGroups {
+		if ng == nil {
+			return fmt.Errorf("invalid ClusterConfig: managedNodeGroups[%d] is not set", i)
+		}
+	}
+	return nil
+}
+
 func makeManagedNodegroup(nodeGroup *api.NodeGroup, options CreateManagedNGOptions) *api.ManagedNodeGroup {
 	ngBase := *nodeGroup.NodeGroupBase
 	if ngBase.SecurityGroups != nil {
@@ -543,6 +564,9 @@ func NewDeleteAndDrainNodeGroupLoader(cmd *Cmd, ng *api.NodeGroup, ngFilter *fil
 	l := newCommonClusterConfigLoader(cmd)
 
 	l.validateWithConfigFile = func() error {
+		if err := validateUnsetNodeGroups(l.ClusterConfig); err != nil {
+			return err
+		}
 		return ngFilter.AppendGlobs(l.Include, l.Exclude, l.ClusterConfig.GetAllNodeGroupNames())
 	}
 
